--
-- HelpWindowModifier
--
-- @author: Jakob Tischler
-- @version: 0.2
-- @date: 22 Aug 2014
-- @history: 0.1 (20 Feb 2014): initial implementation
--           0.2 (22 Aug 2014): * add font size
--                              * adjust width to font size
--                              * add config file save/load
-- adopted as helpHUD V2.0: 14-08-23
-- Copyright (C) 2014 Jakob Tischler



local modItem = ModsUtil.findModItemByModName(g_currentModName);
HelpWindowModifier = {
	modName = g_currentModName;
	version = modItem.version;
	author = modItem.author;
};

addModEventListener(HelpWindowModifier);

function HelpWindowModifier:loadMap(name)
	local fontFactor, widthFactor, opacity = 0.7, 1.2, 0.7;

	-- CONFIG FILE
	local configFilePath = getUserProfileAppPath() .. 'helpHud.xml';
	local configFile;

	-- LOAD
	if fileExists(configFilePath) then
		configFile = loadXMLFile('helpHud', configFilePath, 'helpHud');

		fontFactor = getXMLFloat(configFile, 'helpHud#fontSizeFactor') or fontFactor;
		widthFactor = getXMLFloat(configFile, 'helpHud#widthFactor') or widthFactor;
		opacity = getXMLFloat(configFile, 'helpHud#opacity') or opacity;

	-- CREATE
	else
		configFile = createXMLFile('helpHud', configFilePath, 'helpHud');
		setXMLString(configFile, 'helpHud#fontSizeFactor', ('%.1f'):format(fontFactor));
		setXMLString(configFile, 'helpHud#widthFactor', ('%.1f'):format(widthFactor));
		setXMLString(configFile, 'helpHud#opacity', ('%.1f'):format(opacity));
		saveXMLFile(configFile);
	end;
	if configFile then
		delete(configFile);
	end;

	self:changeFontSize(fontFactor);
	self:changeWidth(fontFactor * widthFactor, fontFactor);
	self:setAlpha(opacity);
	print(('## %s v%.1f by %s initialized --> help window font size set to %d%%, size set to %d%%, opacity set to %d%%'):format(HelpWindowModifier.modName, HelpWindowModifier.version, HelpWindowModifier.author, fontFactor * 100, widthFactor * 100, opacity * 100));
end;

function HelpWindowModifier:changeWidth(widthFactor, fontFactor)
	g_currentMission.hudHelpBaseWidth = g_currentMission.hudHelpBaseWidth * widthFactor;
	g_currentMission.hudHelpBaseTopOverlay.width    = g_currentMission.hudHelpBaseWidth;
	g_currentMission.hudHelpBaseMiddleOverlay.width = g_currentMission.hudHelpBaseWidth;
	g_currentMission.hudHelpBaseBottomOverlay.width = g_currentMission.hudHelpBaseWidth;

	local hPadding = (g_currentMission.hudHelpTextPosX1 - g_currentMission.hudHelpBasePosX) * fontFactor;
	g_currentMission.hudHelpTextPosX1 = g_currentMission.hudHelpBasePosX + hPadding;
	g_currentMission.hudHelpTextPosX2 = g_currentMission.hudHelpBasePosX + g_currentMission.hudHelpBaseWidth - hPadding;
end;

function HelpWindowModifier:setAlpha(a)
	g_currentMission.hudHelpBaseTopOverlay:setColor(1, 1, 1, a);
	g_currentMission.hudHelpBaseMiddleOverlay:setColor(1, 1, 1, a);
	g_currentMission.hudHelpBaseBottomOverlay:setColor(1, 1, 1, a);

	if a < 0.3 then
		g_currentMission.hudHelpTextColor = { 0.9411, 0.9411, 0.9411, 1 };
	end;
end;

function HelpWindowModifier:changeFontSize(factor)
	g_currentMission.hudHelpTextSize = g_currentMission.hudHelpTextSize * factor;
	g_currentMission.hudHelpTextLineSpacing = g_currentMission.hudHelpTextLineSpacing * factor;
	g_currentMission.hudHelpTextMaxHeight = g_currentMission.hudHelpTextMaxHeight / factor;
end;

function HelpWindowModifier:deleteMap() end;
function HelpWindowModifier:update(dt) end;
function HelpWindowModifier:draw() end;
function HelpWindowModifier:keyEvent(unicode, sym, modifier, isDown) end;
function HelpWindowModifier:mouseEvent(posX, posY, isDown, isUp, button) end;


